{
  config,
  lib,
  pkgs,
  mods,
  sources,
  ...
}:

{
  imports = [
    ./hardware-configuration.nix
    # ./router.nix
  ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.supportedFilesystems = [ "bcachefs" ];
  boot.kernelPackages = pkgs.linuxPackages_latest;

  networking.networkmanager.enable = true;
  time.timeZone = "Europe/Paris";

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "fr";
  };

  nixpkgs.config.allowUnfree = true;

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };
  hardware = {
    bluetooth = {
      enable = true;
      powerOnBoot = false;
    };
  };

  environment.systemPackages = with pkgs; [
    (pkgs.callPackage "${toString sources.agenix}/pkgs/agenix.nix" { })
    wget
    brightnessctl
    nix-search-cli
    git
    btop
    ranger
    colmena
    tree
    lazygit
    nix-output-monitor
    ripgrep
  ];
  fonts.packages = with pkgs; [
    fira-code-nerdfont
    font-awesome
  ];

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  services.syncthing = {
    enable = true;
    systemService = true;
    dataDir = "/home/catvayor";
    user = "catvayor";
    group = "users";
    openDefaultPorts = true;
    settings = {
      folders."essentials" = {
        path = "~/essentials";
        id = "vgpwu-fk3ct";
        devices = [
          "katest"
          "katel"
        ];
      };
      devices.katest.id = "UPVXT7D-ZQF4E3J-4WKLLRV-2KF7323-7VOMEJJ-4PZVXW4-UQ2YABE-G7ID4AD";
      devices.katel.id = "DYOKK7J-HZAF5S7-FYTHQF5-UD5GJZ2-4JMV5I5-STUM3HG-5YM2JPR-LATJNAZ";
    };
  };
  services.netbird.enable = true;

  programs.steam.enable = true;

  # boot.kernelModules = [ "kvm-intel" "kvm-amd" ];
  programs.virt-manager.enable = true;
  # virtualisation.libvirtd.enable = true;

  system.stateVersion = "23.11";
}
